@@ -10,13 +10,14 @@ from pathlib import Path
 from subprocess import run
 from sys import exit as sys_exit
 from typing import Union, List
+from shutil import which
 
 # PyPi
 from pydymenu import fzf
 
 # Project Modules
 from mydot.console import console
-from mydot.exceptions import MissingRepositoryLocation
+from mydot.exceptions import MissingRepositoryLocation, WorktreeMissing
 
 
 class Dotfiles:
@@ -25,41 +26,38 @@ class Dotfiles:
         git_dir: Union[str, None] = None,
         work_tree: Union[str, None] = None,
     ):
-        self.bare_repo = self._resolve_repo_location(git_dir)
-        self.work_tree = self._resolve_work_tree_location(work_tree)
+        self.bare_repo: Path = self._resolve_repo_location(git_dir)
+        self.work_tree: Path = self._resolve_work_tree_location(work_tree)
         self._git_base = [
             "git",
             f"--git-dir={self.bare_repo}",
             f"--work-tree={self.work_tree}",
         ]
-        # console.log(f"{self.bare_repo = }")
-        # console.log(f"{self.work_tree = }")
-        # console.log(f"{self._git_base = }")
+        self.run_from: Path = Path.cwd()
         chdir(self.work_tree)
 
-    def _resolve_repo_location(self, path_loc: Union[str, None]) -> Path:
+    @staticmethod
+    def _resolve_repo_location(path_loc: Union[str, None]) -> Path:
         if path_loc is None:
             if env_val := getenv("DOTFILES", default=None):
                 return Path(env_val)
             else:
                 raise MissingRepositoryLocation(
-                    "Could not find an environment value for 'DOTFILES'"
+                    "No repository specified and no value for $DOTFILES in environment."
                 )
         else:
             return Path(path_loc)
 
     @staticmethod
-    def _resolve_work_tree_location(work_tree_str: Union[str, None]) -> Path:
-        if work_tree_str is None:
+    def _resolve_work_tree_location(dir: Union[str, None]) -> Path:
+        if dir is None:
             return Path.home()
         else:
-            work_tree = Path(work_tree_str)
-            if work_tree.is_dir():
+            if (work_tree := Path(dir)).is_dir():
                 return work_tree
             else:
-                raise OSError(
-                    "Missing work-tree directory!\n" f"{work_tree} doesn't exist"
-                )
+                msg = "Missing work-tree directory!\n" f"{work_tree} doesn't exist"
+                raise WorktreeMissing(msg)
 
     def show_status(self) -> None:
         """Short pretty formatted info on current repo."""
@@ -68,8 +66,25 @@ class Dotfiles:
         console.print("\nModified Files:", style="header")
         run(self._git_base + ["status", "-s"])
 
+    @cached_property
+    def preview_app(self) -> str:
+        """Return: bat > batcat > cat"""
+        if which("bat"):
+            return "bat --color=always"
+        elif which("batcat"):
+            return "batcat --color=always"
+        elif which("highlight"):
+            return "highlight -O ansi"
+        else:
+            return "cat"
+
     def choose_files(self) -> List[str]:
-        select = fzf(self.list_all, prompt="Pick file(s) to edit: ", multi=True)
+        select = fzf(
+            self.list_all,
+            prompt="Pick file(s) to edit: ",
+            multi=True,
+            preview=f"{self.preview_app}" + " {}",
+        )
         if select is None:
             sys_exit("No selection made. Cancelling action.")
         else:
@@ -86,17 +101,16 @@ class Dotfiles:
                 cmd = [self.editor, edits[0]]
             else:
                 cmd = [self.editor, "-o"] + edits
-            console.log(edits, log_locals=True)
+            # console.log(edits, log_locals=True)
             run(cmd)
 
     def add(self) -> Union[List[str], None]:
         git = " ".join(self._git_base).strip()
-        modified = self.modified
-        if modified is None:
+        if self.modified is None:
             sys_exit("Clean work tree. No unstaged changes present.")
         else:
             adding = fzf(
-                modified,
+                self.modified,
                 prompt="Choose changes to add: ",
                 multi=True,
                 preview=f"{git} diff --color --minimal HEAD -- " + "{}",
@@ -123,21 +137,40 @@ class Dotfiles:
     def tracked(self) -> List[str]:
         # TODO: try this: $ git ls-files --others --cached
         cmd = self._git_base + ["ls-tree", "--full-tree", "--full-name", "-r", "HEAD"]
-        out = run(cmd, text=True, capture_output=True).stdout.strip()
-        lines = out.split("\n")
+        lines = run(cmd, text=True, capture_output=True).stdout.strip().split("\n")
         tracked = [item.split("\t")[-1] for item in lines]
         return tracked
 
     @cached_property
     def staged_adds(self) -> List[str]:
-        lines = self.short_status.split("\n")
-        return [" ".join(fp.split()[1:]) for fp in lines if fp[0] == "A"]
+        if len(self.short_status) == 0:
+            return []
+        else:
+            lines = self.short_status.split("\n")
+            return [" ".join(fp.split()[1:]) for fp in lines if fp[0] == "A"]
+
+    @cached_property
+    def renames(self) -> List[str]:
+        if len(self.short_status) == 0:
+            return []
+        else:
+            lines = self.short_status.split("\n")
+            rename_lines = [l for l in lines if l[0] == "R"]
+            if len(rename_lines) > 0:
+                rename_files = [f.split(" -> ")[1] for f in rename_lines]
+                return rename_files
+            else:
+                return []
+            # print(f"{rename_lines =}")
+            # renames = [" ".join(fp.split()[1:]) for fp in lines if fp[0] == "A"]
+            # return renames
 
     @cached_property
     def list_all(self) -> List[str]:
         adds = self.staged_adds
         tracked = self.tracked
-        return sorted(adds + tracked)
+        renames = self.renames
+        return sorted(adds + tracked + renames)
 
     @cached_property
     def modified(self) -> Union[List[str], None]:
@@ -152,4 +185,4 @@ class Dotfiles:
         return [l.split()[1] for l in self.short_status.split("\n")]
 
 
-# vim: foldlevel=5 :
+# vim: foldlevel=1 :
